summaryrefslogtreecommitdiffstats
path: root/perl-install/install2.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/install2.pm')
-rw-r--r--perl-install/install2.pm3
1 files changed, 1 insertions, 2 deletions
diff --git a/perl-install/install2.pm b/perl-install/install2.pm
index 5c916e5bd..bd3d92b18 100644
--- a/perl-install/install2.pm
+++ b/perl-install/install2.pm
@@ -329,7 +329,7 @@ sub start_i810fb() {
log::l("trying to load i810fb module with xres <$xres> (vga was <$vga>)");
eval { modules::load('intel-agp') };
eval {
- any::ddcxinfos(); # keep the result otherwise ddcxinfos does not return good results afterwards
+ any::monitor_full_edid(); # keep the result otherwise monitor-edid does not return good results afterwards
my $opt = "xres=$xres hsync1=32 hsync2=48 vsync1=50 vsync2=70 vram=2 bpp=16 accel=1 mtrr=1"; #- this sucking i810fb does not accept floating point numbers in hsync!
modules::load_with_options([ 'i810fb' ], { i810fb => $opt });
};
@@ -450,7 +450,6 @@ sub main {
$o->{prefix} = $::prefix = $::testing ? "/tmp/test-perl-install" : $::move ? "" : "/mnt";
mkdir $o->{prefix}, 0755;
- devices::make("/dev/zero"); #- needed by ddcxinfos
#- make sure we do not pick up any gunk from the outside world
my $remote_path = "$o->{prefix}/sbin:$o->{prefix}/bin:$o->{prefix}/usr/sbin:$o->{prefix}/usr/bin:$o->{prefix}/usr/X11R6/bin";